@@ -33,6 +33,7 @@
 #ifdef HAVE_MEEGO
 #include <mx-gtk/mx-gtk.h>
 #endif /* HAVE_MEEGO */
+#include <gio/gdesktopappinfo.h>
 
 #include <libempathy/empathy-utils.h>
 
@@ -111,11 +112,58 @@ enum {
 
 static void account_widget_apply_and_log_in (EmpathyAccountWidget *);
 
+enum {
+  RESPONSE_LAUNCH
+};
+
 static guint signals[LAST_SIGNAL] = { 0 };
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountWidget)
 #define CHANGED_TIMEOUT 300
 
+#define DIGIT             "0-9"
+#define DIGITS            "(["DIGIT"]+)"
+#define ALPHA             "a-zA-Z"
+#define ALPHAS            "(["ALPHA"]+)"
+#define ALPHADIGIT        ALPHA DIGIT
+#define ALPHADIGITS       "(["ALPHADIGIT"]+)"
+#define ALPHADIGITDASH    ALPHA DIGIT "-"
+#define ALPHADIGITDASHS   "(["ALPHADIGITDASH"]*)"
+
+#define HOSTNUMBER        "("DIGITS"\\."DIGITS"\\."DIGITS"\\."DIGITS")"
+#define TOPLABEL          ALPHAS"|(["ALPHA"]" ALPHADIGITDASHS "["ALPHADIGIT"])"
+#define DOMAINLABEL       ALPHADIGITS"|(["ALPHADIGIT"]" ALPHADIGITDASHS \
+                                       "["ALPHADIGIT"])"
+#define HOSTNAME          "((" DOMAINLABEL "\\.)+" TOPLABEL ")"
+/* Based on http://www.ietf.org/rfc/rfc1738.txt (section 5) */
+#define HOST              "("HOSTNAME "|" HOSTNUMBER")"
+/* Based on http://www.ietf.org/rfc/rfc0822.txt (appendix D) */
+#define EMAIL_LOCALPART   "([^\\(\\)<>@,;:\\\\\"\\[\\]\\s]+)"
+
+/* UIN is digital according to the unofficial specification:
+ * http://iserverd.khstu.ru/docum_ext/icqv5.html#CTS
+ * 5 digits minimun according to http://en.wikipedia.org/wiki/ICQ#UIN */
+#define ICQ_USER_NAME     "(["DIGIT"]{5,})"
+/* Based on http://www.ietf.org/rfc/rfc2812.txt (section 2.3.1) */
+#define IRC_SPECIAL       "_\\[\\]{}\\\\|`^"
+#define IRC_USER_NAME     "(["ALPHA IRC_SPECIAL"]["ALPHADIGITDASH IRC_SPECIAL"]*)"
+/* Based on http://www.ietf.org/rfc/rfc4622.txt (section 2.2)
+ * We just exclude invalid characters to avoid ucschars and other redundant
+ * complexity */
+#define JABBER_USER_NAME  "([^@:'\"<>&\\s]+)"
+/* ID is an email according to the unofficial specification:
+ * http://www.hypothetic.org/docs/msn/general/names.php */
+#define MSN_USER_NAME     EMAIL_LOCALPART
+/* Based on the official help:
+ * http://help.yahoo.com/l/us/yahoo/edit/registration/edit-01.html */
+#define YAHOO_USER_NAME   "(["ALPHA"]["ALPHADIGIT"_\\.]{3,31})"
+
+#define ACCOUNT_REGEX_ICQ      "^"ICQ_USER_NAME"$"
+#define ACCOUNT_REGEX_IRC      "^"IRC_USER_NAME"$"
+#define ACCOUNT_REGEX_JABBER   "^"JABBER_USER_NAME"@"HOST"$"
+#define ACCOUNT_REGEX_MSN      "^"MSN_USER_NAME"@"HOST"$"
+#define ACCOUNT_REGEX_YAHOO    "^"YAHOO_USER_NAME"$"
+
 static void
 account_widget_set_control_buttons_sensitivity (EmpathyAccountWidget *self,
     gboolean sensitive)
@@ -135,6 +183,35 @@ account_widget_set_control_buttons_sensitivity (EmpathyAccountWidget *self,
     }
 }
 
+static void
+account_widget_set_entry_highlighting (GtkEntry *entry, gboolean highlight)
+{
+  GdkColor color;
+  GtkStyle *style;
+
+  g_return_if_fail (GTK_IS_ENTRY (entry));
+
+  style = gtk_widget_get_style (GTK_WIDGET (entry));
+
+  if (highlight)
+    {
+      color = style->bg[GTK_STATE_SELECTED];
+
+      /* Here we take the current theme colour and add it to
+       * the colour for white and average the two. This
+       * gives a colour which is inline with the theme but
+       * slightly whiter.
+       */
+      color.red = (color.red + (style->white).red) / 2;
+      color.green = (color.green + (style->white).green) / 2;
+      color.blue = (color.blue + (style->white).blue) / 2;
+
+      gtk_widget_modify_base (GTK_WIDGET (entry), GTK_STATE_NORMAL, &color);
+    }
+  else
+    gtk_widget_modify_base (GTK_WIDGET (entry), GTK_STATE_NORMAL, NULL);
+}
+
 static void
 account_widget_handle_control_buttons_sensitivity (EmpathyAccountWidget *self)
 {
@@ -156,9 +233,13 @@ account_widget_entry_changed_common (EmpathyAccountWidget *self,
   const gchar *str;
   const gchar *param_name;
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+  gboolean prev_status;
+  gboolean curr_status;
 
   str = gtk_entry_get_text (entry);
   param_name = g_object_get_data (G_OBJECT (entry), "param_name");
+  prev_status = empathy_account_settings_parameter_is_valid (priv->settings,
+                                                             param_name);
 
   if (EMP_STR_EMPTY (str))
     {
@@ -180,6 +261,11 @@ account_widget_entry_changed_common (EmpathyAccountWidget *self,
           tp_strdiff (param_name, "password") ? str : "***");
       empathy_account_settings_set_string (priv->settings, param_name, str);
     }
+
+  curr_status = empathy_account_settings_parameter_is_valid (priv->settings,
+                                                             param_name);
+  if (curr_status != prev_status)
+    account_widget_set_entry_highlighting (entry, !curr_status);
 }
 
 static void
@@ -190,6 +276,21 @@ account_widget_entry_changed_cb (GtkEditable *entry,
   empathy_account_widget_changed (self);
 }
 
+static void
+account_widget_entry_map_cb (GtkEntry *entry,
+    EmpathyAccountWidget *self)
+{
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+  const gchar *param_name;
+  gboolean is_valid;
+
+  /* need to initialize input highlighting */
+  param_name = g_object_get_data (G_OBJECT (entry), "param_name");
+  is_valid = empathy_account_settings_parameter_is_valid (priv->settings,
+                                                          param_name);
+  account_widget_set_entry_highlighting (entry, !is_valid);
+}
+
 static void
 account_widget_int_changed_cb (GtkWidget *widget,
     EmpathyAccountWidget *self)
@@ -451,6 +552,8 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
 
       g_signal_connect (widget, "changed",
           G_CALLBACK (account_widget_entry_changed_cb), self);
+      g_signal_connect (widget, "map",
+          G_CALLBACK (account_widget_entry_map_cb), self);
     }
   else if (GTK_IS_TOGGLE_BUTTON (widget))
     {
@@ -914,6 +1017,100 @@ account_widget_build_generic (EmpathyAccountWidget *self,
         G_CALLBACK (account_widget_settings_ready_cb), self);
 }
 
+static void
+account_widget_launch_external_clicked (GtkWidget *button,
+    TpAccount *account)
+{
+  if (!tp_strdiff (tp_account_get_storage_provider (account),
+        "com.meego.libsocialweb"))
+    {
+      /* we know how to handle this external provider */
+      GDesktopAppInfo *app_info;
+      const gchar *args[3] = { NULL, };
+      GError *error = NULL;
+
+      app_info = g_desktop_app_info_new ("gnome-control-center.desktop");
+
+      if (app_info == NULL)
+        {
+          g_critical ("Could not locate 'gnome-control-center.desktop'");
+          return;
+        }
+
+      args[0] = g_app_info_get_commandline (G_APP_INFO (app_info));
+      args[1] = "bisho.desktop";
+      args[2] = NULL;
+
+      gdk_spawn_on_screen (gtk_widget_get_screen (button),
+          NULL, (gchar **) args, NULL,
+          G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error);
+      if (error != NULL)
+        {
+          g_critical ("Failed to launch editor: %s", error->message);
+          g_clear_error (&error);
+        }
+
+      g_object_unref (app_info);
+    }
+}
+
+static void
+account_widget_build_external (EmpathyAccountWidget *self,
+    EmpathyAccountSettings *settings)
+{
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+  TpAccount *account = empathy_account_settings_get_account (settings);
+  GtkWidget *bar, *widget;
+  gchar *str;
+
+  self->ui_details->widget = gtk_vbox_new (FALSE, 6);
+  priv->table_common_settings = gtk_table_new (1, 2, FALSE);
+
+  if (!tp_strdiff (tp_account_get_storage_provider (account),
+        "com.meego.libsocialweb"))
+    {
+      /* we know how to handle this external provider */
+      str = g_strdup_printf (
+          _("The account %s is edited via My Web Accounts."),
+          empathy_account_settings_get_display_name (settings));
+    }
+  else
+    {
+      str = g_strdup_printf (
+          _("The account %s cannot be edited in Empathy."),
+          empathy_account_settings_get_display_name (settings));
+    }
+
+  widget = gtk_label_new (str);
+  gtk_label_set_line_wrap (GTK_LABEL (widget), TRUE);
+  g_free (str);
+
+  bar = gtk_info_bar_new ();
+  gtk_info_bar_set_message_type (GTK_INFO_BAR (bar), GTK_MESSAGE_INFO);
+  gtk_container_add (
+      GTK_CONTAINER (gtk_info_bar_get_content_area (GTK_INFO_BAR (bar))),
+      widget);
+  gtk_container_set_border_width (GTK_CONTAINER (bar), 6);
+
+  if (!tp_strdiff (tp_account_get_storage_provider (account),
+        "com.meego.libsocialweb"))
+    {
+      /* we know how to handle this external provider */
+      widget = gtk_info_bar_add_button (GTK_INFO_BAR (bar),
+          _("Launch My Web Accounts"), RESPONSE_LAUNCH);
+
+      g_signal_connect (widget, "clicked",
+          G_CALLBACK (account_widget_launch_external_clicked), account);
+    }
+
+  gtk_box_pack_start (GTK_BOX (self->ui_details->widget), bar,
+      FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (self->ui_details->widget),
+      priv->table_common_settings, FALSE, TRUE, 0);
+
+  gtk_widget_show_all (self->ui_details->widget);
+}
+
 static void
 account_widget_build_salut (EmpathyAccountWidget *self,
     const char *filename)
@@ -948,6 +1145,9 @@ account_widget_build_irc (EmpathyAccountWidget *self,
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
 
+  empathy_account_settings_set_regex (priv->settings, "account",
+      ACCOUNT_REGEX_IRC);
+
   if (priv->simple)
     {
       priv->irc_network_chooser = empathy_account_widget_irc_build_simple (self,
@@ -975,6 +1175,9 @@ account_widget_build_msn (EmpathyAccountWidget *self,
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
 
+  empathy_account_settings_set_regex (priv->settings, "account",
+      ACCOUNT_REGEX_MSN);
+
   if (priv->simple)
     {
       self->ui_details->gui = empathy_builder_get_file (filename,
@@ -1104,6 +1307,9 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
   is_gtalk = account_widget_is_gtalk (self);
   is_facebook = account_widget_is_facebook (self);
 
+  empathy_account_settings_set_regex (priv->settings, "account",
+      ACCOUNT_REGEX_JABBER);
+
   if (priv->simple && !is_gtalk && !is_facebook)
     {
       /* Simple widget for XMPP */
@@ -1228,6 +1434,9 @@ account_widget_build_icq (EmpathyAccountWidget *self,
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   GtkWidget *spinbutton_port;
 
+  empathy_account_settings_set_regex (priv->settings, "account",
+      ACCOUNT_REGEX_ICQ);
+
   if (priv->simple)
     {
       self->ui_details->gui = empathy_builder_get_file (filename,
@@ -1306,6 +1515,9 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
 
+  empathy_account_settings_set_regex (priv->settings, "account",
+      ACCOUNT_REGEX_YAHOO);
+
   if (priv->simple)
     {
       self->ui_details->gui = empathy_builder_get_file (filename,
@@ -1710,7 +1922,6 @@ do_constructed (GObject *obj)
   EmpathyAccountWidget *self = EMPATHY_ACCOUNT_WIDGET (obj);
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   TpAccount *account;
-  const gchar *protocol, *cm_name;
   const gchar *display_name, *default_display_name;
   guint i = 0;
   struct {
@@ -1731,31 +1942,46 @@ do_constructed (GObject *obj)
     WIDGET (sofiasip, sip),
   };
 
-  cm_name = empathy_account_settings_get_cm (priv->settings);
-  protocol = empathy_account_settings_get_protocol (priv->settings);
+  account = empathy_account_settings_get_account (priv->settings);
 
-  for (i = 0 ; i < G_N_ELEMENTS (widgets); i++)
+  /* Empathy can only edit accounts without the Cannot_Set_Parameters flag */
+  if (tp_account_get_storage_restrictions (account) &
+      TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS)
     {
-      if (!tp_strdiff (widgets[i].cm_name, cm_name) &&
-          !tp_strdiff (widgets[i].protocol, protocol))
-        {
-          gchar *filename;
+      DEBUG ("Account is provided by an external storage provider");
 
-          filename = empathy_file_lookup (widgets[i].file,
-              "libempathy-gtk");
-          widgets[i].func (self, filename);
-          g_free (filename);
-
-          break;
-        }
+      account_widget_build_external (self, priv->settings);
     }
-
-  if (i == G_N_ELEMENTS (widgets))
+  else
     {
-      gchar *filename = empathy_file_lookup (
-          "empathy-account-widget-generic.ui", "libempathy-gtk");
-      account_widget_build_generic (self, filename);
-      g_free (filename);
+      const gchar *protocol, *cm_name;
+
+      cm_name = empathy_account_settings_get_cm (priv->settings);
+      protocol = empathy_account_settings_get_protocol (priv->settings);
+
+      for (i = 0 ; i < G_N_ELEMENTS (widgets); i++)
+        {
+          if (!tp_strdiff (widgets[i].cm_name, cm_name) &&
+              !tp_strdiff (widgets[i].protocol, protocol))
+            {
+              gchar *filename;
+
+              filename = empathy_file_lookup (widgets[i].file,
+                  "libempathy-gtk");
+              widgets[i].func (self, filename);
+              g_free (filename);
+
+              break;
+            }
+        }
+
+      if (i == G_N_ELEMENTS (widgets))
+        {
+          gchar *filename = empathy_file_lookup (
+              "empathy-account-widget-generic.ui", "libempathy-gtk");
+          account_widget_build_generic (self, filename);
+          g_free (filename);
+        }
     }
 
   /* handle default focus */
@@ -1778,7 +2004,9 @@ do_constructed (GObject *obj)
       account_manager_ready_cb, self);
 
   /* handle apply and cancel button */
-  if (!priv->simple)
+  if (!priv->simple &&
+      !(tp_account_get_storage_restrictions (account) &
+        TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS))
     {
       GtkWidget *hbox = gtk_hbox_new (TRUE, 3);
       GtkWidget *image;
@@ -1827,8 +2055,6 @@ do_constructed (GObject *obj)
         account_widget_set_control_buttons_sensitivity (self, FALSE);
     }
 
-  account = empathy_account_settings_get_account (priv->settings);
-
   if (account != NULL)
     {
       g_signal_connect (account, "notify::enabled",
@@ -1838,15 +2064,22 @@ do_constructed (GObject *obj)
 #ifndef HAVE_MEEGO
   add_register_buttons (self, account);
 #endif /* HAVE_MEEGO */
-  add_enable_checkbox (self, account);
+
+  /* add the Enable checkbox to accounts that support it */
+  if (!(tp_account_get_storage_restrictions (account) &
+      TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED))
+    add_enable_checkbox (self, account);
 
   /* hook up to widget destruction to unref ourselves */
   g_signal_connect (self->ui_details->widget, "destroy",
       G_CALLBACK (account_widget_destroy_cb), self);
 
-  empathy_builder_unref_and_keep_widget (self->ui_details->gui,
-      self->ui_details->widget);
-  self->ui_details->gui = NULL;
+  if (self->ui_details->gui != NULL)
+    {
+      empathy_builder_unref_and_keep_widget (self->ui_details->gui,
+          self->ui_details->widget);
+      self->ui_details->gui = NULL;
+    }
 
   display_name = empathy_account_settings_get_display_name (priv->settings);
   default_display_name = empathy_account_widget_get_default_display_name (self);
