@@ -32,14 +32,15 @@
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include <gconf/gconf-client.h>
 
 #include <telepathy-glib/util.h>
 
+#include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-utils.h>
 
 #include "empathy-chat-text-view.h"
 #include "empathy-chat.h"
-#include "empathy-conf.h"
 #include "empathy-ui-utils.h"
 #include "empathy-smiley-manager.h"
 #include "empathy-string-parser.h"
@@ -68,6 +69,7 @@ typedef struct {
 	time_t                last_timestamp;
 	gboolean              allow_scrolling;
 	guint                 notify_system_fonts_id;
+	GConfClient          *gconf_client;
 	EmpathySmileyManager *smiley_manager;
 	gboolean              only_if_date;
 } EmpathyChatTextViewPriv;
@@ -203,17 +205,20 @@ chat_text_view_create_tags (EmpathyChatTextView *view)
 static void
 chat_text_view_system_font_update (EmpathyChatTextView *view)
 {
+	EmpathyChatTextViewPriv *priv = GET_PRIV (view);
 	PangoFontDescription *font_description = NULL;
 	gchar                *font_name;
 
-	if (empathy_conf_get_string (empathy_conf_get (),
-				     "/desktop/gnome/interface/document_font_name",
-				     &font_name) && font_name) {
-					     font_description = pango_font_description_from_string (font_name);
-					     g_free (font_name);
-				     } else {
-					     font_description = NULL;
-				     }
+	font_name = gconf_client_get_string (priv->gconf_client,
+			"/desktop/gnome/interface/document_font_name",
+			NULL);
+
+	if (font_name != NULL) {
+		font_description = pango_font_description_from_string (font_name);
+		g_free (font_name);
+	} else {
+		font_description = NULL;
+	}
 
 	gtk_widget_modify_font (GTK_WIDGET (view), font_description);
 
@@ -223,9 +228,10 @@ chat_text_view_system_font_update (EmpathyChatTextView *view)
 }
 
 static void
-chat_text_view_notify_system_font_cb (EmpathyConf *conf,
-				      const gchar *key,
-				      gpointer     user_data)
+chat_text_view_notify_system_font_cb (GConfClient *conf,
+				      guint id,
+				      GConfEntry *entry,
+				      gpointer user_data)
 {
 	EmpathyChatTextView *view = user_data;
 
@@ -268,11 +274,11 @@ chat_text_view_populate_popup (EmpathyChatTextView *view,
 	/* Clear menu item */
 	if (gtk_text_buffer_get_char_count (priv->buffer) > 0) {
 		item = gtk_separator_menu_item_new ();
-		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 		gtk_widget_show (item);
 
 		item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLEAR, NULL);
-		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 		gtk_widget_show (item);
 
 		g_signal_connect_swapped (item, "activate",
@@ -333,23 +339,18 @@ chat_text_view_populate_popup (EmpathyChatTextView *view,
 static gboolean
 chat_text_view_is_scrolled_down (EmpathyChatTextView *view)
 {
-	GtkWidget *sw;
+	GtkAdjustment *vadj;
+	gdouble value;
+	gdouble upper;
+	gdouble page_size;
 
-	sw = gtk_widget_get_parent (GTK_WIDGET (view));
-	if (GTK_IS_SCROLLED_WINDOW (sw)) {
-		GtkAdjustment *vadj;
-		gdouble value;
-		gdouble upper;
-		gdouble page_size;
+	vadj = gtk_text_view_get_vadjustment (GTK_TEXT_VIEW (view));
+	value = gtk_adjustment_get_value (vadj);
+	upper = gtk_adjustment_get_upper (vadj);
+	page_size = gtk_adjustment_get_page_size (vadj);
 
-		vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
-		value = gtk_adjustment_get_value (vadj);
-		upper = gtk_adjustment_get_upper (vadj);
-		page_size = gtk_adjustment_get_page_size (vadj);
-
-		if (value < upper - page_size) {
-			return FALSE;
-		}
+	if (value < upper - page_size) {
+		return FALSE;
 	}
 
 	return TRUE;
@@ -442,8 +443,6 @@ chat_text_view_append_timestamp (EmpathyChatTextView *view,
 						  EMPATHY_CHAT_TEXT_VIEW_TAG_TIME,
 						  NULL);
 
-	priv->last_timestamp = timestamp;
-
 	g_string_free (str, TRUE);
 }
 
@@ -496,7 +495,7 @@ chat_text_view_size_allocate (GtkWidget     *widget,
 	if (down) {
 		GtkAdjustment *adj;
 
-		adj = GTK_TEXT_VIEW (widget)->vadjustment;
+		adj = gtk_text_view_get_vadjustment (GTK_TEXT_VIEW (widget));
 		gtk_adjustment_set_value (adj,
 					  gtk_adjustment_get_upper (adj) -
 					  gtk_adjustment_get_page_size (adj));
@@ -566,7 +565,9 @@ chat_text_view_finalize (GObject *object)
 
 	DEBUG ("%p", object);
 
-	empathy_conf_notify_remove (empathy_conf_get (), priv->notify_system_fonts_id);
+	gconf_client_notify_remove (priv->gconf_client,
+				    priv->notify_system_fonts_id);
+	g_object_unref (priv->gconf_client);
 
 	if (priv->last_contact) {
 		g_object_unref (priv->last_contact);
@@ -641,11 +642,16 @@ empathy_chat_text_view_init (EmpathyChatTextView *view)
 		      "cursor-visible", FALSE,
 		      NULL);
 
+	priv->gconf_client = gconf_client_get_default ();
+	gconf_client_add_dir (priv->gconf_client,
+			      "/desktop/gnome/interface",
+			      GCONF_CLIENT_PRELOAD_ONELEVEL,
+			      NULL);
 	priv->notify_system_fonts_id =
-		empathy_conf_notify_add (empathy_conf_get (),
+		gconf_client_notify_add (priv->gconf_client,
 					 "/desktop/gnome/interface/document_font_name",
 					 chat_text_view_notify_system_font_cb,
-					 view);
+					 view, NULL, NULL);
 	chat_text_view_system_font_update (view);
 	chat_text_view_create_tags (view);
 
@@ -655,6 +661,18 @@ empathy_chat_text_view_init (EmpathyChatTextView *view)
 			  NULL);
 }
 
+static void
+chat_text_view_scroll_stop (EmpathyChatTextView *view)
+{
+	EmpathyChatTextViewPriv *priv = GET_PRIV (view);
+
+	g_timer_destroy (priv->scroll_time);
+	priv->scroll_time = NULL;
+
+	g_source_remove (priv->scroll_timeout);
+	priv->scroll_timeout = 0;
+}
+
 /* Code stolen from pidgin/gtkimhtml.c */
 static gboolean
 chat_text_view_scroll_cb (EmpathyChatTextView *view)
@@ -664,7 +682,8 @@ chat_text_view_scroll_cb (EmpathyChatTextView *view)
 	gdouble             max_val;
 
 	priv = GET_PRIV (view);
-	adj = GTK_TEXT_VIEW (view)->vadjustment;
+
+	adj = gtk_text_view_get_vadjustment (GTK_TEXT_VIEW (view));
 	max_val = gtk_adjustment_get_upper (adj) - gtk_adjustment_get_page_size (adj);
 
 	g_return_val_if_fail (priv->scroll_time != NULL, FALSE);
@@ -672,9 +691,7 @@ chat_text_view_scroll_cb (EmpathyChatTextView *view)
 	if (g_timer_elapsed (priv->scroll_time, NULL) > MAX_SCROLL_TIME) {
 		/* time's up. jump to the end and kill the timer */
 		gtk_adjustment_set_value (adj, max_val);
-		g_timer_destroy (priv->scroll_time);
-		priv->scroll_time = NULL;
-		priv->scroll_timeout = 0;
+		chat_text_view_scroll_stop (view);
 		return FALSE;
 	}
 
@@ -744,6 +761,8 @@ chat_text_view_append_message (EmpathyChatView *view,
 	}
 	priv->last_contact = g_object_ref (empathy_message_get_sender (msg));
 	g_object_notify (G_OBJECT (view), "last-contact");
+
+	priv->last_timestamp = timestamp;
 }
 
 static void
@@ -1308,6 +1327,16 @@ empathy_chat_text_view_get_last_contact (EmpathyChatTextView *view)
 	return priv->last_contact;
 }
 
+time_t
+empathy_chat_text_view_get_last_timestamp (EmpathyChatTextView *view)
+{
+	EmpathyChatTextViewPriv *priv = GET_PRIV (view);
+
+	g_return_val_if_fail (EMPATHY_IS_CHAT_TEXT_VIEW (view), 0);
+
+	return priv->last_timestamp;
+}
+
 void
 empathy_chat_text_view_set_only_if_date (EmpathyChatTextView *view,
 					 gboolean             only_if_date)
@@ -1389,11 +1418,13 @@ empathy_chat_text_view_append_body (EmpathyChatTextView *view,
 	GtkTextIter              start_iter;
 	GtkTextIter              iter;
 	GtkTextMark             *mark;
+	GSettings		*gsettings_chat;
 
 	/* Check if we have to parse smileys */
-	empathy_conf_get_bool (empathy_conf_get (),
-			       EMPATHY_PREFS_CHAT_SHOW_SMILEYS,
-			       &use_smileys);
+	gsettings_chat = g_settings_new (EMPATHY_PREFS_CHAT_SCHEMA);
+	use_smileys = g_settings_get_boolean (gsettings_chat,
+			EMPATHY_PREFS_CHAT_SHOW_SMILEYS);
+
 	if (use_smileys)
 		parsers = string_parsers_with_smiley;
 	else
@@ -1418,6 +1449,8 @@ empathy_chat_text_view_append_body (EmpathyChatTextView *view,
 					   &iter);
 
 	gtk_text_buffer_delete_mark (priv->buffer, mark);
+
+	g_object_unref (gsettings_chat);
 }
 
 void
