@@ -243,10 +243,8 @@ entry_activate_cb (GtkEntry *entry,
   gtk_dialog_response (GTK_DIALOG (self), GTK_RESPONSE_ACCEPT);
 }
 
-static void
+static gboolean
 account_chooser_filter (TpAccount *account,
-    EmpathyAccountChooserFilterResultCallback callback,
-    gpointer callback_data,
     gpointer user_data)
 {
   EmpathyContactSelectorDialog *self = user_data;
@@ -254,13 +252,9 @@ account_chooser_filter (TpAccount *account,
       EMPATHY_CONTACT_SELECTOR_DIALOG_GET_CLASS (self);
 
   if (class->account_filter == NULL)
-    {
-      empathy_account_chooser_filter_is_connected (
-          account,callback, callback_data, user_data);
-      return;
-    }
+    return empathy_account_chooser_filter_is_connected (account, user_data);
 
-  class->account_filter (self, callback, callback_data, account);
+  return class->account_filter (self, account);
 }
 
 static gboolean
