@@ -132,7 +132,7 @@ individual_can_audio_video_call (FolksIndividual *individual,
       TpContact *tp_contact;
       EmpathyContact *contact;
 
-      if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+      if (!TPF_IS_PERSONA (l->data))
         continue;
 
       tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
@@ -158,8 +158,7 @@ static void
 add_individual_to_store (GtkTreeStore *self,
     GtkTreeIter *iter,
     GtkTreeIter *parent,
-    FolksIndividual *individual,
-    EmpathyIndividualManagerFlags flags)
+    FolksIndividual *individual)
 {
   gboolean can_audio_call, can_video_call;
 
@@ -168,11 +167,10 @@ add_individual_to_store (GtkTreeStore *self,
 
   gtk_tree_store_insert_with_values (self, iter, parent, 0,
       EMPATHY_INDIVIDUAL_STORE_COL_NAME,
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+      folks_individual_get_alias (individual),
       EMPATHY_INDIVIDUAL_STORE_COL_INDIVIDUAL, individual,
       EMPATHY_INDIVIDUAL_STORE_COL_IS_GROUP, FALSE,
       EMPATHY_INDIVIDUAL_STORE_COL_IS_SEPARATOR, FALSE,
-      EMPATHY_INDIVIDUAL_STORE_COL_FLAGS, flags,
       EMPATHY_INDIVIDUAL_STORE_COL_CAN_AUDIO_CALL, can_audio_call,
       EMPATHY_INDIVIDUAL_STORE_COL_CAN_VIDEO_CALL, can_video_call,
       -1);
@@ -326,13 +324,6 @@ individual_store_find_contact (EmpathyIndividualStore *self,
   return l;
 }
 
-static void
-free_iters (GList *iters)
-{
-  g_list_foreach (iters, (GFunc) gtk_tree_iter_free, NULL);
-  g_list_free (iters);
-}
-
 static void
 individual_store_remove_individual (EmpathyIndividualStore *self,
     FolksIndividual *individual)
@@ -369,7 +360,8 @@ individual_store_remove_individual (EmpathyIndividualStore *self,
         }
     }
 
-  free_iters (iters);
+  g_list_foreach (iters, (GFunc) gtk_tree_iter_free, NULL);
+  g_list_free (iters);
 }
 
 static void
@@ -382,24 +374,21 @@ individual_store_add_individual (EmpathyIndividualStore *self,
   GList *groups = NULL, *l;
   EmpathyContact *contact;
   TpConnection *connection;
-  EmpathyIndividualManagerFlags flags = 0;
   gchar *protocol_name;
 
   priv = GET_PRIV (self);
 
-  if (EMP_STR_EMPTY (folks_aliasable_get_alias (FOLKS_ALIASABLE (individual))))
+  if (EMP_STR_EMPTY (folks_individual_get_alias (individual)))
     return;
 
   if (priv->show_groups)
     {
-      group_set = folks_groupable_get_groups (FOLKS_GROUPABLE (individual));
+      group_set = folks_individual_get_groups (individual);
       groups = g_hash_table_get_keys (group_set);
     }
 
   contact = empathy_contact_dup_from_folks_individual (individual);
   connection = empathy_contact_get_connection (contact);
-  flags = empathy_individual_manager_get_flags_for_connection (priv->manager,
-      connection);
 
   tp_connection_parse_object_path (connection, &protocol_name, NULL);
 
@@ -426,7 +415,7 @@ individual_store_add_individual (EmpathyIndividualStore *self,
         }
 
       add_individual_to_store (GTK_TREE_STORE (self), &iter, parent,
-          individual, flags);
+          individual);
     }
 
   g_free (protocol_name);
@@ -440,12 +429,14 @@ individual_store_add_individual (EmpathyIndividualStore *self,
           FALSE);
 
       add_individual_to_store (GTK_TREE_STORE (self), &iter, &iter_group,
-          individual, flags);
+          individual);
     }
   g_list_free (groups);
+  if (group_set != NULL)
+    g_hash_table_unref (group_set);
 
   if (priv->show_groups &&
-      folks_favouritable_get_is_favourite (FOLKS_FAVOURITABLE (individual)))
+      folks_favourite_get_is_favourite (FOLKS_FAVOURITE (individual)))
     {
       /* Add contact to the fake 'Favorites' group */
       GtkTreeIter iter_group;
@@ -454,7 +445,7 @@ individual_store_add_individual (EmpathyIndividualStore *self,
           &iter_group, NULL, NULL, TRUE);
 
       add_individual_to_store (GTK_TREE_STORE (self), &iter, &iter_group,
-          individual, flags);
+          individual);
     }
 
   individual_store_contact_update (self, individual);
@@ -494,7 +485,9 @@ individual_store_contact_set_active (EmpathyIndividualStore *self,
         }
     }
 
-  free_iters (iters);
+  g_list_foreach (iters, (GFunc) gtk_tree_iter_free, NULL);
+  g_list_free (iters);
+
 }
 
 static void individual_store_contact_active_free (ShowActiveData *data);
@@ -525,8 +518,7 @@ individual_store_contact_active_new (EmpathyIndividualStore *self,
   ShowActiveData *data;
 
   DEBUG ("Individual'%s' now active, and %s be removed",
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
-      remove_ ? "WILL" : "WILL NOT");
+      folks_individual_get_alias (individual), remove_ ? "WILL" : "WILL NOT");
 
   data = g_slice_new0 (ShowActiveData);
 
@@ -570,12 +562,12 @@ individual_store_contact_active_cb (ShowActiveData *data)
   if (data->remove)
     {
       DEBUG ("Individual'%s' active timeout, removing item",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (data->individual)));
+          folks_individual_get_alias (data->individual));
       individual_store_remove_individual (data->self, data->individual);
     }
 
   DEBUG ("Individual'%s' no longer active",
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (data->individual)));
+      folks_individual_get_alias (data->individual));
 
   individual_store_contact_set_active (data->self,
       data->individual, FALSE, TRUE);
@@ -604,7 +596,7 @@ individual_avatar_pixbuf_received_cb (FolksIndividual *individual,
   if (error != NULL)
     {
       DEBUG ("failed to retrieve pixbuf for individual %s: %s",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+          folks_individual_get_alias (individual),
           error->message);
       g_clear_error (&error);
     }
@@ -619,8 +611,6 @@ individual_avatar_pixbuf_received_cb (FolksIndividual *individual,
               EMPATHY_INDIVIDUAL_STORE_COL_PIXBUF_AVATAR, pixbuf,
               -1);
         }
-
-      free_iters (iters);
     }
 
   /* Free things */
@@ -634,7 +624,6 @@ individual_avatar_pixbuf_received_cb (FolksIndividual *individual,
           data->cancellable);
     }
 
-  tp_clear_object (&pixbuf);
   g_object_unref (data->cancellable);
   g_slice_free (LoadAvatarData, data);
 }
@@ -673,13 +662,12 @@ individual_store_contact_update (EmpathyIndividualStore *self,
     }
 
   /* Get online state now. */
-  now_online = folks_presence_owner_is_online (
-      FOLKS_PRESENCE_OWNER (individual));
+  now_online = folks_individual_is_online (individual);
 
   if (!in_list)
     {
       DEBUG ("Individual'%s' in list:NO, should be:YES",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+          folks_individual_get_alias (individual));
 
       individual_store_add_individual (self, individual);
 
@@ -693,7 +681,7 @@ individual_store_contact_update (EmpathyIndividualStore *self,
   else
     {
       DEBUG ("Individual'%s' in list:YES, should be:YES",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+          folks_individual_get_alias (individual));
 
       /* Get online state before. */
       if (iters && g_list_length (iters) > 0)
@@ -759,13 +747,11 @@ individual_store_contact_update (EmpathyIndividualStore *self,
           EMPATHY_INDIVIDUAL_STORE_COL_ICON_STATUS, pixbuf_status,
           EMPATHY_INDIVIDUAL_STORE_COL_PIXBUF_AVATAR_VISIBLE, show_avatar,
           EMPATHY_INDIVIDUAL_STORE_COL_NAME,
-            folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+            folks_individual_get_alias (individual),
           EMPATHY_INDIVIDUAL_STORE_COL_PRESENCE_TYPE,
-            folks_presence_owner_get_presence_type (
-                FOLKS_PRESENCE_OWNER (individual)),
+            folks_individual_get_presence_type (individual),
           EMPATHY_INDIVIDUAL_STORE_COL_STATUS,
-            folks_presence_owner_get_presence_message (
-                FOLKS_PRESENCE_OWNER (individual)),
+            folks_individual_get_presence_message (individual),
           EMPATHY_INDIVIDUAL_STORE_COL_COMPACT, priv->is_compact,
           EMPATHY_INDIVIDUAL_STORE_COL_IS_GROUP, FALSE,
           EMPATHY_INDIVIDUAL_STORE_COL_IS_ONLINE, now_online,
@@ -795,7 +781,8 @@ individual_store_contact_update (EmpathyIndividualStore *self,
    * timeout removes the user from the contact list, really we
    * should remove the first timeout.
    */
-  free_iters (iters);
+  g_list_foreach (iters, (GFunc) gtk_tree_iter_free, NULL);
+  g_list_free (iters);
 }
 
 static void
@@ -804,7 +791,7 @@ individual_store_individual_updated_cb (FolksIndividual *individual,
     EmpathyIndividualStore *self)
 {
   DEBUG ("Individual'%s' updated, checking roster is in sync...",
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+      folks_individual_get_alias (individual));
 
   individual_store_contact_update (self, individual);
 }
@@ -1352,9 +1339,8 @@ individual_store_contact_sort (FolksIndividual *individual_a,
   g_return_val_if_fail (individual_a != NULL || individual_b != NULL, 0);
 
   /* alias */
-  ret_val = g_utf8_collate (
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual_a)),
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual_b)));
+  ret_val = g_utf8_collate (folks_individual_get_alias (individual_a),
+      folks_individual_get_alias (individual_b));
 
   if (ret_val != 0)
     goto out;
@@ -1425,12 +1411,8 @@ individual_store_state_sort_func (GtkTreeModel *model,
   /* If we managed to get this far, we can start looking at
    * the presences.
    */
-  folks_presence_type_a =
-      folks_presence_owner_get_presence_type (
-          FOLKS_PRESENCE_OWNER (individual_a));
-  folks_presence_type_b =
-      folks_presence_owner_get_presence_type (
-          FOLKS_PRESENCE_OWNER (individual_b));
+  folks_presence_type_a = folks_individual_get_presence_type (individual_a);
+  folks_presence_type_b = folks_individual_get_presence_type (individual_b);
   tp_presence_a = empathy_folks_presence_type_to_tp (folks_presence_type_a);
   tp_presence_b = empathy_folks_presence_type_to_tp (folks_presence_type_b);
 
@@ -1483,8 +1465,6 @@ individual_store_name_sort_func (GtkTreeModel *model,
 
   tp_clear_object (&individual_a);
   tp_clear_object (&individual_b);
-  g_free (name_a);
-  g_free (name_b);
 
   return ret_val;
 }
@@ -1508,7 +1488,6 @@ individual_store_setup (EmpathyIndividualStore *self)
     G_TYPE_BOOLEAN,             /* Is separator */
     G_TYPE_BOOLEAN,             /* Can make audio calls */
     G_TYPE_BOOLEAN,             /* Can make video calls */
-    EMPATHY_TYPE_INDIVIDUAL_MANAGER_FLAGS,      /* Flags */
     G_TYPE_BOOLEAN,             /* Is a fake group */
   };
 
@@ -1912,7 +1891,7 @@ individual_store_get_individual_status_icon_with_icon_name (
   personas = folks_individual_get_personas (individual);
   for (l = personas, contact_count = 0; l; l = l->next)
     {
-      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+      if (TPF_IS_PERSONA (l->data))
         contact_count++;
 
       if (contact_count > 1)
