@@ -31,12 +31,8 @@
 #include <gtk/gtk.h>
 
 #include <telepathy-glib/account-manager.h>
-#include <telepathy-glib/proxy-subclass.h>
-
 #include <telepathy-logger/log-manager.h>
 
-#include <extensions/extensions.h>
-
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-chatroom.h>
 #include <libempathy/empathy-message.h>
@@ -65,7 +61,7 @@ typedef struct {
 	GtkWidget         *button_previous;
 	GtkWidget         *button_next;
 
-	GtkWidget         *hbox_chats;
+	GtkWidget         *vbox_chats;
 	GtkWidget         *account_chooser_chats;
 	GtkWidget         *entry_chats;
 	GtkWidget         *calendar_chats;
@@ -109,7 +105,8 @@ static void     log_window_chats_accounts_changed_cb       (GtkWidget        *co
 static void     log_window_chats_set_selected              (EmpathyLogWindow *window);
 static gboolean log_window_chats_get_selected              (EmpathyLogWindow *window,
 							    TpAccount       **account,
-							    TplEntity        **target);
+							    gchar           **chat_id,
+							    gboolean         *is_chatroom);
 static void     log_window_chats_get_messages              (EmpathyLogWindow *window,
 							    GDate      *date_to_show);
 static void     log_window_calendar_chats_day_selected_cb  (GtkWidget        *calendar,
@@ -120,21 +117,14 @@ static void     log_window_entry_chats_changed_cb          (GtkWidget        *en
 							    EmpathyLogWindow *window);
 static void     log_window_entry_chats_activate_cb         (GtkWidget        *entry,
 							    EmpathyLogWindow *window);
-static void     log_window_delete_menu_clicked_cb          (GtkMenuItem      *menuitem,
-							    EmpathyLogWindow *window);
-
-static void
-empathy_account_chooser_filter_has_logs (TpAccount *account,
-					 EmpathyAccountChooserFilterResultCallback callback,
-					 gpointer callback_data,
-					 gpointer user_data);
 
 enum {
 	COL_FIND_ACCOUNT_ICON,
 	COL_FIND_ACCOUNT_NAME,
 	COL_FIND_ACCOUNT,
 	COL_FIND_CHAT_NAME,
-	COL_FIND_TARGET,
+	COL_FIND_CHAT_ID,
+	COL_FIND_IS_CHATROOM,
 	COL_FIND_DATE,
 	COL_FIND_DATE_READABLE,
 	COL_FIND_COUNT
@@ -144,7 +134,8 @@ enum {
 	COL_CHAT_ICON,
 	COL_CHAT_NAME,
 	COL_CHAT_ACCOUNT,
-	COL_CHAT_TARGET,
+	COL_CHAT_ID,
+	COL_CHAT_IS_CHATROOM,
 	COL_CHAT_COUNT
 };
 
@@ -174,7 +165,13 @@ account_manager_prepared_cb (GObject *source_object,
 	account_num = g_list_length (accounts);
 	g_list_free (accounts);
 
-	gtk_widget_show_all (window->hbox_chats);
+	if (account_num > 1) {
+		gtk_widget_show (window->vbox_chats);
+		gtk_widget_show (window->account_chooser_chats);
+	} else {
+		gtk_widget_hide (window->vbox_chats);
+		gtk_widget_hide (window->account_chooser_chats);
+	}
 }
 
 static void
@@ -224,8 +221,6 @@ empathy_log_window_show (TpAccount  *account,
 	GtkBuilder             *gui;
 	gchar                  *filename;
 	EmpathyLogWindow       *window;
-	EmpathyThemeManager    *theme_mgr;
-	GtkWidget *menu_delete;
 
 	if (log_window != NULL) {
 		gtk_window_present (GTK_WINDOW (log_window->window));
@@ -247,7 +242,6 @@ empathy_log_window_show (TpAccount  *account,
 					"libempathy-gtk");
 	gui = empathy_builder_get_file (filename,
 				       "log_window", &window->window,
-				       "menu_delete", &menu_delete,
 				       "notebook", &window->notebook,
 				       "entry_find", &window->entry_find,
 				       "button_find", &window->button_find,
@@ -257,7 +251,7 @@ empathy_log_window_show (TpAccount  *account,
 				       "button_next", &window->button_next,
 				       "entry_chats", &window->entry_chats,
 				       "calendar_chats", &window->calendar_chats,
-				       "hbox_chats", &window->hbox_chats,
+				       "vbox_chats", &window->vbox_chats,
 				       "treeview_chats", &window->treeview_chats,
 				       "scrolledwindow_chats", &window->scrolledwindow_chats,
 				       NULL);
@@ -272,7 +266,6 @@ empathy_log_window_show (TpAccount  *account,
 			      "button_find", "clicked", log_window_button_find_clicked_cb,
 			      "entry_chats", "changed", log_window_entry_chats_changed_cb,
 			      "entry_chats", "activate", log_window_entry_chats_activate_cb,
-			      "menu_delete", "activate", log_window_delete_menu_clicked_cb,
 			      NULL);
 
 	g_object_unref (gui);
@@ -289,25 +282,22 @@ empathy_log_window_show (TpAccount  *account,
 			  window);
 
 	/* Configure Search EmpathyChatView */
-	theme_mgr = empathy_theme_manager_dup_singleton ();
-	window->chatview_find = empathy_theme_manager_create_view (theme_mgr);
+	window->chatview_find = empathy_theme_manager_create_view (empathy_theme_manager_get ());
 	gtk_container_add (GTK_CONTAINER (window->scrolledwindow_find),
 			   GTK_WIDGET (window->chatview_find));
 	gtk_widget_show (GTK_WIDGET (window->chatview_find));
 
 	/* Configure Contacts EmpathyChatView */
-	window->chatview_chats = empathy_theme_manager_create_view (theme_mgr);
+	window->chatview_chats = empathy_theme_manager_create_view (empathy_theme_manager_get ());
 	gtk_container_add (GTK_CONTAINER (window->scrolledwindow_chats),
 			   GTK_WIDGET (window->chatview_chats));
 	gtk_widget_show (GTK_WIDGET (window->chatview_chats));
-	g_object_unref (theme_mgr);
 
 	/* Account chooser for chats */
 	window->account_chooser_chats = empathy_account_chooser_new ();
 	account_chooser = EMPATHY_ACCOUNT_CHOOSER (window->account_chooser_chats);
-	empathy_account_chooser_set_filter (account_chooser, empathy_account_chooser_filter_has_logs, NULL);
 
-	gtk_box_pack_start (GTK_BOX (window->hbox_chats),
+	gtk_box_pack_start (GTK_BOX (window->vbox_chats),
 			    window->account_chooser_chats,
 			    FALSE, TRUE, 0);
 
@@ -374,7 +364,7 @@ log_window_entry_find_changed_cb (GtkWidget       *entry,
 }
 
 static void
-got_events_for_date_cb (GObject *manager,
+got_messages_for_date_cb (GObject *manager,
                        GAsyncResult *result,
                        gpointer user_data)
 {
@@ -388,7 +378,7 @@ got_events_for_date_cb (GObject *manager,
 	if (log_window == NULL)
 		return;
 
-	if (!tpl_log_manager_get_events_for_date_finish (TPL_LOG_MANAGER (manager),
+	if (!tpl_log_manager_get_messages_for_date_finish (TPL_LOG_MANAGER (manager),
 		result, &messages, &error)) {
 			DEBUG ("Unable to retrieve messages for the selected date: %s. Aborting",
 					error->message);
@@ -401,9 +391,9 @@ got_events_for_date_cb (GObject *manager,
 	for (l = messages; l; l = l->next) {
 			EmpathyMessage *message;
 
-			g_assert (TPL_IS_EVENT (l->data));
+			g_assert (TPL_IS_ENTRY (l->data));
 
-			message = empathy_message_from_tpl_log_event (l->data);
+			message = empathy_message_from_tpl_log_entry (l->data);
 			g_object_unref (l->data);
 			empathy_chat_view_append_message (window->chatview_find, message);
 			g_object_unref (message);
@@ -458,7 +448,8 @@ log_window_find_changed_cb (GtkTreeSelection *selection,
 	GtkTreeModel  *model;
 	GtkTreeIter    iter;
 	TpAccount     *account;
-	TplEntity     *target;
+	gchar         *chat_id;
+	gboolean       is_chatroom;
 	gchar         *date;
 	GDate         *gdate;
 
@@ -480,7 +471,8 @@ log_window_find_changed_cb (GtkTreeSelection *selection,
 
 	gtk_tree_model_get (model, &iter,
 			    COL_FIND_ACCOUNT, &account,
-			    COL_FIND_TARGET, &target,
+			    COL_FIND_CHAT_ID, &chat_id,
+			    COL_FIND_IS_CHATROOM, &is_chatroom,
 			    COL_FIND_DATE, &date,
 			    -1);
 
@@ -494,20 +486,20 @@ log_window_find_changed_cb (GtkTreeSelection *selection,
 	gdate = gdate_from_str (date);
 
 	if (gdate != NULL) {
-		tpl_log_manager_get_events_for_date_async (window->log_manager,
-							   account,
-							   target,
-							   TPL_EVENT_MASK_TEXT,
-							   gdate,
-							   got_events_for_date_cb,
-							   window);
+		tpl_log_manager_get_messages_for_date_async (window->log_manager,
+								      account,
+								      chat_id,
+								      is_chatroom,
+								      gdate,
+								      got_messages_for_date_cb,
+								      window);
 
 		g_date_free (gdate);
 	}
 
 	g_object_unref (account);
-	g_object_unref (target);
 	g_free (date);
+	g_free (chat_id);
 }
 
 
@@ -542,7 +534,7 @@ log_manager_searched_new_cb (GObject *manager,
 			hit = l->data;
 
 			/* Protect against invalid data (corrupt or old log files. */
-			if (hit->account == NULL || hit->target == NULL) {
+			if (hit->account == NULL || hit->chat_id == NULL) {
 					continue;
 			}
 
@@ -560,14 +552,15 @@ log_manager_searched_new_cb (GObject *manager,
 					COL_FIND_ACCOUNT_ICON, account_icon,
 					COL_FIND_ACCOUNT_NAME, account_name,
 					COL_FIND_ACCOUNT, hit->account,
-					COL_FIND_CHAT_NAME, tpl_entity_get_alias (hit->target),
-					COL_FIND_TARGET, hit->target,
+					COL_FIND_CHAT_NAME, hit->chat_id, /* FIXME */
+					COL_FIND_CHAT_ID, hit->chat_id,
+					COL_FIND_IS_CHATROOM, hit->is_chatroom,
 					COL_FIND_DATE, tmp,
 					COL_FIND_DATE_READABLE, date_readable,
 					-1);
 
 			/* FIXME: Update COL_FIND_CHAT_NAME */
-			if (tpl_entity_get_entity_type (hit->target) == TPL_ENTITY_ROOM) {
+			if (hit->is_chatroom) {
 			} else {
 			}
 	}
@@ -600,8 +593,7 @@ log_window_find_populate (EmpathyLogWindow *window,
 		return;
 	}
 
-	tpl_log_manager_search_async (window->log_manager,
-			search_criteria, TPL_EVENT_MASK_TEXT,
+	tpl_log_manager_search_async (window->log_manager, search_criteria,
 			log_manager_searched_new_cb, (gpointer) store);
 }
 
@@ -626,7 +618,8 @@ log_window_find_setup (EmpathyLogWindow *window)
 				    G_TYPE_STRING,          /* account name */
 				    TP_TYPE_ACCOUNT,        /* account */
 				    G_TYPE_STRING,          /* chat name */
-				    TPL_TYPE_ENTITY,        /* target */
+				    G_TYPE_STRING,          /* chat id */
+				    G_TYPE_BOOLEAN,         /* is chatroom */
 				    G_TYPE_STRING,          /* date */
 				    G_TYPE_STRING);         /* date_readable */
 
@@ -781,14 +774,12 @@ log_window_chats_changed_cb (GtkTreeSelection *selection,
 }
 
 static void
-log_manager_got_entities_cb (GObject *manager,
-			     GAsyncResult *result,
-			     gpointer user_data)
+log_manager_got_chats_cb (GObject *manager,
+                       GAsyncResult *result,
+                       gpointer user_data)
 {
 	EmpathyLogWindow      *window = user_data;
-	EmpathyAccountChooser *account_chooser;
-	TpAccount             *account;
-	GList                 *entities;
+	GList                 *chats;
 	GList                 *l;
 	GtkTreeView           *view;
 	GtkTreeModel          *model;
@@ -798,16 +789,11 @@ log_manager_got_entities_cb (GObject *manager,
 	GError                *error = NULL;
 	gboolean               select_account = FALSE;
 
-	account_chooser = EMPATHY_ACCOUNT_CHOOSER (window->account_chooser_chats);
-	account = empathy_account_chooser_get_account (account_chooser);
-
-	view = GTK_TREE_VIEW (window->treeview_chats);
-
 	if (log_window == NULL)
 		return;
 
-	if (!tpl_log_manager_get_entities_finish (TPL_LOG_MANAGER (manager),
-		result, &entities, &error)) {
+	if (!tpl_log_manager_get_chats_finish (TPL_LOG_MANAGER (manager),
+		result, &chats, &error)) {
 			DEBUG ("%s. Aborting", error->message);
 			g_error_free (error);
 			return;
@@ -818,30 +804,34 @@ log_manager_got_entities_cb (GObject *manager,
 	selection = gtk_tree_view_get_selection (view);
 	store = GTK_LIST_STORE (model);
 
-	for (l = entities; l; l = l->next) {
-		TplEntity *entity;
+	for (l = chats; l; l = l->next) {
+			TplLogSearchHit *hit;
 
-		entity = TPL_ENTITY (l->data);
+			hit = l->data;
 
-		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter,
-				COL_CHAT_ICON, "empathy-available", /* FIXME */
-				COL_CHAT_NAME, tpl_entity_get_alias (entity),
-				COL_CHAT_ACCOUNT, account,
-				COL_CHAT_TARGET, entity,
-				-1);
+			if (hit->account == NULL)
+				continue;
 
-		if (window->selected_account != NULL &&
-		    !tp_strdiff (tp_proxy_get_object_path (account),
-		    tp_proxy_get_object_path (window->selected_account)))
-			select_account = TRUE;
+			gtk_list_store_append (store, &iter);
+			gtk_list_store_set (store, &iter,
+					COL_CHAT_ICON, "empathy-available", /* FIXME */
+					COL_CHAT_NAME, hit->chat_id,
+					COL_CHAT_ACCOUNT, hit->account,
+					COL_CHAT_ID, hit->chat_id,
+					COL_CHAT_IS_CHATROOM, hit->is_chatroom,
+					-1);
 
-		/* FIXME: Update COL_CHAT_ICON/NAME */
-		if (tpl_entity_get_entity_type (entity) == TPL_ENTITY_ROOM) {
-		} else {
-		}
+			if (window->selected_account != NULL &&
+			    !tp_strdiff (tp_proxy_get_object_path (hit->account),
+			    tp_proxy_get_object_path (window->selected_account)))
+				select_account = TRUE;
+
+			/* FIXME: Update COL_CHAT_ICON/NAME */
+			if (hit->is_chatroom) {
+			} else {
+			}
 	}
-	g_list_free_full (entities, g_object_unref);
+	tpl_log_manager_search_free (chats);
 
 	/* Unblock signals */
 	g_signal_handlers_unblock_by_func (selection,
@@ -885,8 +875,8 @@ log_window_chats_populate (EmpathyLogWindow *window)
 
 	gtk_list_store_clear (store);
 
-	tpl_log_manager_get_entities_async (window->log_manager, account,
-			log_manager_got_entities_cb, (gpointer) window);
+	tpl_log_manager_get_chats_async (window->log_manager, account,
+			log_manager_got_chats_cb, (gpointer) window);
 }
 
 static void
@@ -908,7 +898,8 @@ log_window_chats_setup (EmpathyLogWindow *window)
 				    G_TYPE_STRING,        /* icon */
 				    G_TYPE_STRING,        /* name */
 				    TP_TYPE_ACCOUNT,      /* account */
-				    TPL_TYPE_ENTITY);     /* target */
+				    G_TYPE_STRING,        /* id */
+				    G_TYPE_BOOLEAN);      /* is chatroom */
 
 	model = GTK_TREE_MODEL (store);
 	sortable = GTK_TREE_SORTABLE (store);
@@ -976,19 +967,16 @@ log_window_chats_set_selected (EmpathyLogWindow *window)
 	}
 
 	for (ok = TRUE; ok; ok = gtk_tree_model_iter_next (model, &iter)) {
-		TpAccount   *this_account;
-		TplEntity   *this_target;
-		const gchar *this_chat_id;
-		gboolean     this_is_chatroom;
+		TpAccount *this_account;
+		gchar     *this_chat_id;
+		gboolean   this_is_chatroom;
 
 		gtk_tree_model_get (model, &iter,
 				    COL_CHAT_ACCOUNT, &this_account,
-				    COL_CHAT_TARGET, &this_target,
+				    COL_CHAT_ID, &this_chat_id,
+				    COL_CHAT_IS_CHATROOM, &this_is_chatroom,
 				    -1);
 
-		this_chat_id = tpl_entity_get_identifier (this_target);
-		this_is_chatroom = tpl_entity_get_entity_type (this_target) == TPL_ENTITY_ROOM;
-
 		if (this_account == window->selected_account &&
 		    !tp_strdiff (this_chat_id, window->selected_chat_id) &&
 		    this_is_chatroom == window->selected_is_chatroom) {
@@ -997,12 +985,12 @@ log_window_chats_set_selected (EmpathyLogWindow *window)
 			gtk_tree_view_scroll_to_cell (view, path, NULL, TRUE, 0.5, 0.0);
 			gtk_tree_path_free (path);
 			g_object_unref (this_account);
-			g_object_unref (this_target);
+			g_free (this_chat_id);
 			break;
 		}
 
 		g_object_unref (this_account);
-		g_object_unref (this_target);
+		g_free (this_chat_id);
 	}
 
 	tp_clear_object (&window->selected_account);
@@ -1012,14 +1000,16 @@ log_window_chats_set_selected (EmpathyLogWindow *window)
 static gboolean
 log_window_chats_get_selected (EmpathyLogWindow  *window,
 			       TpAccount       **account,
-			       TplEntity       **target)
+			       gchar           **chat_id,
+			       gboolean         *is_chatroom)
 {
 	GtkTreeView      *view;
 	GtkTreeModel     *model;
 	GtkTreeSelection *selection;
 	GtkTreeIter       iter;
-	TplEntity        *targ;
+	gchar            *id = NULL;
 	TpAccount        *acc = NULL;
+	gboolean          room = FALSE;
 
 	view = GTK_TREE_VIEW (window->treeview_chats);
 	model = gtk_tree_view_get_model (view);
@@ -1031,20 +1021,24 @@ log_window_chats_get_selected (EmpathyLogWindow  *window,
 
 	gtk_tree_model_get (model, &iter,
 			    COL_CHAT_ACCOUNT, &acc,
-			    COL_CHAT_TARGET, &targ,
+			    COL_CHAT_ID, &id,
+			    COL_CHAT_IS_CHATROOM, &room,
 			    -1);
 
+	if (chat_id != NULL) {
+		*chat_id = id;
+	} else {
+		g_free (id);
+	}
 	if (account != NULL) {
-		*account = g_object_ref (acc);
+		*account = acc;
+	} else {
+		g_object_unref (acc);
 	}
-
-	if (target != NULL) {
-		*target = g_object_ref (targ);
+	if (is_chatroom) {
+		*is_chatroom = room;
 	}
 
-	g_object_unref (acc);
-	g_object_unref (targ);
-
 	return TRUE;
 }
 
@@ -1054,15 +1048,15 @@ log_window_got_messages_for_date_cb (GObject *manager,
     gpointer user_data)
 {
   EmpathyLogWindow *window = user_data;
-  GList *events;
+  GList *messages;
   GList *l;
   GError *error = NULL;
 
   if (log_window == NULL)
     return;
 
-  if (!tpl_log_manager_get_events_for_date_finish (TPL_LOG_MANAGER (manager),
-        result, &events, &error)) {
+  if (!tpl_log_manager_get_messages_for_date_finish (TPL_LOG_MANAGER (manager),
+        result, &messages, &error)) {
       DEBUG ("Unable to retrieve messages for the selected date: %s. Aborting",
           error->message);
       empathy_chat_view_append_event (window->chatview_find,
@@ -1071,14 +1065,14 @@ log_window_got_messages_for_date_cb (GObject *manager,
       return;
   }
 
-  for (l = events; l; l = l->next) {
-      EmpathyMessage *message = empathy_message_from_tpl_log_event (l->data);
+  for (l = messages; l; l = l->next) {
+      EmpathyMessage *message = empathy_message_from_tpl_log_entry (l->data);
       g_object_unref (l->data);
       empathy_chat_view_append_message (window->chatview_chats,
           message);
       g_object_unref (message);
   }
-  g_list_free (events);
+  g_list_free (messages);
 
   /* Turn back on scrolling */
   empathy_chat_view_scroll (window->chatview_find, TRUE);
@@ -1093,9 +1087,11 @@ log_window_get_messages_for_date (EmpathyLogWindow *window,
 				  GDate *date)
 {
   TpAccount *account;
-  TplEntity *target;
+  gchar *chat_id;
+  gboolean is_chatroom;
 
-  if (!log_window_chats_get_selected (window, &account, &target)) {
+  if (!log_window_chats_get_selected (window, &account,
+        &chat_id, &is_chatroom)) {
       return;
   }
 
@@ -1105,15 +1101,13 @@ log_window_get_messages_for_date (EmpathyLogWindow *window,
   /* Turn off scrolling temporarily */
   empathy_chat_view_scroll (window->chatview_find, FALSE);
 
-  /* Get events */
-  tpl_log_manager_get_events_for_date_async (window->log_manager,
-      account, target, TPL_EVENT_MASK_TEXT,
+  /* Get messages */
+  tpl_log_manager_get_messages_for_date_async (window->log_manager,
+      account, chat_id,
+      is_chatroom,
       date,
       log_window_got_messages_for_date_cb,
       (gpointer) window);
-
-  g_object_unref (account);
-  g_object_unref (target);
 }
 
 static void
@@ -1201,13 +1195,15 @@ log_window_chats_get_messages (EmpathyLogWindow *window,
 			       GDate     *date)
 {
 	TpAccount     *account;
-	TplEntity     *target;
+	gchar         *chat_id;
+	gboolean       is_chatroom;
 	guint          year_selected;
 	guint          month_selected;
 	guint          day;
 
 
-	if (!log_window_chats_get_selected (window, &account, &target)) {
+	if (!log_window_chats_get_selected (window, &account,
+					    &chat_id, &is_chatroom)) {
 		return;
 	}
 
@@ -1219,7 +1215,8 @@ log_window_chats_get_messages (EmpathyLogWindow *window,
 	if (date == NULL) {
 		/* Get a list of dates and show them on the calendar */
 		tpl_log_manager_get_dates_async (window->log_manager,
-						       account, target, TPL_EVENT_MASK_TEXT,
+						       account, chat_id,
+						       is_chatroom,
 						       log_manager_got_dates_cb, (gpointer) window);
     /* signal unblocked at the end of the CB flow */
 	} else {
@@ -1249,7 +1246,7 @@ log_window_chats_get_messages (EmpathyLogWindow *window,
 	}
 
 	g_object_unref (account);
-	g_object_unref (target);
+	g_free (chat_id);
 }
 
 static void
@@ -1334,23 +1331,25 @@ log_window_calendar_chats_month_changed_cb (GtkWidget       *calendar,
 					    EmpathyLogWindow *window)
 {
 	TpAccount     *account;
-	TplEntity     *target;
+	gchar         *chat_id;
+	gboolean       is_chatroom;
 
 	gtk_calendar_clear_marks (GTK_CALENDAR (calendar));
 
-	if (!log_window_chats_get_selected (window, &account, &target)) {
+	if (!log_window_chats_get_selected (window, &account,
+					    &chat_id, &is_chatroom)) {
 		DEBUG ("No chat selected to get dates for...");
 		return;
 	}
 
 	/* Get the log object for this contact */
-	tpl_log_manager_get_dates_async (window->log_manager, account, target,
-					       TPL_EVENT_MASK_TEXT,
+	tpl_log_manager_get_dates_async (window->log_manager, account,
+					       chat_id, is_chatroom,
 					       log_window_updating_calendar_month_cb,
 					       (gpointer) window);
 
 	g_object_unref (account);
-	g_object_unref (target);
+	g_free (chat_id);
 }
 
 static void
@@ -1385,165 +1384,3 @@ log_window_entry_chats_activate_cb (GtkWidget       *entry,
 					    FALSE);
 	}
 }
-
-typedef struct {
-	EmpathyAccountChooserFilterResultCallback callback;
-	gpointer                                  user_data;
-} FilterCallbackData;
-
-static void
-got_entities (GObject      *manager,
-	      GAsyncResult *result,
-	      gpointer      user_data)
-{
-	FilterCallbackData *data = user_data;
-	GList *entities;
-	GError *error;
-
-	if (!tpl_log_manager_get_entities_finish (TPL_LOG_MANAGER (manager), result, &entities, &error)) {
-		DEBUG ("Could not get entities: %s", error->message);
-		g_error_free (error);
-		data->callback (FALSE, data->user_data);
-	} else {
-		data->callback (entities != NULL, data->user_data);
-
-		g_list_free_full (entities, g_object_unref);
-	}
-
-	g_slice_free (FilterCallbackData, data);
-}
-
-static void
-empathy_account_chooser_filter_has_logs (TpAccount *account,
-					 EmpathyAccountChooserFilterResultCallback callback,
-					 gpointer callback_data,
-					 gpointer user_data)
-{
-	TplLogManager *manager = tpl_log_manager_dup_singleton ();
-	FilterCallbackData *cb_data = g_slice_new0 (FilterCallbackData);
-
-	cb_data->callback = callback;
-	cb_data->user_data = callback_data;
-
-	tpl_log_manager_get_entities_async (manager, account, got_entities, cb_data);
-
-	g_object_unref (manager);
-}
-
-static void
-log_window_logger_clear_account_cb (TpProxy *proxy,
-				    const GError *error,
-				    gpointer user_data,
-				    GObject *weak_object)
-{
-	EmpathyLogWindow *window = user_data;
-
-	if (error != NULL)
-		g_warning ("Error when clearing logs: %s", error->message);
-
-	/* Refresh the log viewer so the logs are cleared if the account
-	 * has been deleted */
-	empathy_chat_view_clear (window->chatview_chats);
-	log_window_chats_populate (window);
-
-	/* Re-filter the account chooser so the accounts without logs get greyed out */
-	empathy_account_chooser_set_filter (EMPATHY_ACCOUNT_CHOOSER (window->account_chooser_chats),
-					    empathy_account_chooser_filter_has_logs, NULL);
-}
-
-static void
-log_window_clear_logs_chooser_select_account (EmpathyAccountChooser *chooser,
-					      EmpathyLogWindow *window)
-{
-	empathy_account_chooser_set_account (chooser,
-		empathy_account_chooser_get_account (EMPATHY_ACCOUNT_CHOOSER (window->account_chooser_chats)));
-}
-
-static void
-log_window_delete_menu_clicked_cb (GtkMenuItem      *menuitem,
-				   EmpathyLogWindow *window)
-{
-	GtkWidget *dialog, *content_area, *hbox, *label;
-	EmpathyAccountChooser *account_chooser;
-	gint response_id;
-	TpDBusDaemon *bus;
-	TpProxy *logger;
-	GError *error = NULL;
-
-	account_chooser = (EmpathyAccountChooser *) empathy_account_chooser_new ();
-	empathy_account_chooser_set_has_all_option (account_chooser, TRUE);
-	empathy_account_chooser_set_filter (account_chooser, empathy_account_chooser_filter_has_logs, NULL);
-
-	/* Select the same account as in the history window */
-	if (empathy_account_chooser_is_ready (account_chooser))
-		log_window_clear_logs_chooser_select_account (account_chooser, window);
-	else
-		g_signal_connect (account_chooser, "ready",
-				  G_CALLBACK (log_window_clear_logs_chooser_select_account), window);
-
-	dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window->window),
-		GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING,
-		GTK_BUTTONS_NONE,
-		_("Are you sure you want to delete all logs of previous conversations?"));
-
-	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		_("Clear All"), GTK_RESPONSE_APPLY,
-		NULL);
-
-	content_area = gtk_message_dialog_get_message_area (
-		GTK_MESSAGE_DIALOG (dialog));
-
-	hbox = gtk_hbox_new (FALSE, 6);
-	label = gtk_label_new (_("Delete from:"));
-	gtk_box_pack_start (GTK_BOX (hbox), label,
-		FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (account_chooser),
-		FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (content_area), hbox,
-		FALSE, FALSE, 0);
-
-	gtk_widget_show_all (hbox);
-
-	response_id = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	if (response_id != GTK_RESPONSE_APPLY)
-		goto out;
-
-	bus = tp_dbus_daemon_dup (&error);
-	if (error != NULL) {
-		g_warning ("Could not delete logs: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	logger = g_object_new (TP_TYPE_PROXY,
-			       "bus-name", "org.freedesktop.Telepathy.Logger",
-			       "object-path", "/org/freedesktop/Telepathy/Logger",
-			       "dbus-daemon", bus,
-			       NULL);
-	g_object_unref (bus);
-
-	tp_proxy_add_interface_by_id (logger, EMP_IFACE_QUARK_LOGGER);
-
-	if (empathy_account_chooser_has_all_selected (account_chooser)) {
-		DEBUG ("Deleting logs for all the accounts");
-
-		emp_cli_logger_call_clear (logger, -1,
-					   log_window_logger_clear_account_cb,
-					   window, NULL, G_OBJECT (window->window));
-	} else {
-		TpAccount *account = empathy_account_chooser_get_account (account_chooser);
-
-		DEBUG ("Deleting logs for %s", tp_proxy_get_object_path (account));
-
-		emp_cli_logger_call_clear_account (logger, -1,
-						   tp_proxy_get_object_path (account),
-						   log_window_logger_clear_account_cb,
-						   window, NULL, G_OBJECT (window->window));
-	}
-
-	g_object_unref (logger);
- out:
-	gtk_widget_destroy (dialog);
-}
